@@ -57,8 +57,6 @@ q#
 --   http://wiki.postgresql.org/wiki/Audit_trigger
 -- but has been completely rewritten.
 --
--- Should really be converted into a relocatable EXTENSION, with control and upgrade files.
-CREATE EXTENSION IF NOT EXISTS hstore
 #,
 
 q#
